`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////
// Company: Worcester Polytechnic Institute
// Engineer: Kazim Shaikh
// Edited By: Dario Martinovic, Michael Padberg
//
// Create Date: 01/21/2018
// Module Name: color_logic
//
// Description: This module takes in five input signals from the vga controller
//              and gives an output to the VGA monitor.
// 
// 
//////////////////////////////////////////////////////////////////////////////////

module color_logic(
input blank,                // input from vga_controller. It determines if pixels are visible on the screen
input [10:0] vcount ,       // input from vga_controller. It describes the vertical location of a pixel from 0 to 479.
input [1:0] color_signal,   // input from IR_top for color display based on object position.
input [10:0] hcount ,       // input from vga_controller. It describes the horizontal location of a pixel from 0 to 649.
output reg [11:0] clr_rgb   // output describing red, green and blue 
    );
          
//Color parameters
parameter YELLOW = 12'hF0F;
parameter RED = 12'h00F;
parameter BLACK = 12'h000;
parameter WHITE = 12'hFFF;
parameter GREEN = 12'hF00;


//display a color to fill the screen based on the input from IR_top
always @ (blank, color_signal, clr_rgb) begin
    if (blank == 0) begin
        case(color_signal)
            2'b01 : clr_rgb = YELLOW;
            2'b10 : clr_rgb = RED; 
            default: clr_rgb =  GREEN;
        endcase
    end
    else begin
        clr_rgb = BLACK;    //if blank signal =1, display no color.
    end
end          

endmodule